from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Tax(_message.Message):
    __slots__ = [
        "id",
        "code",
        "name",
        "description",
        "amount_type",
        "type_tax_use",
        "amount",
        "tax_scope",
        "active",
        "external_id",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_TYPE_FIELD_NUMBER: _ClassVar[int]
    TYPE_TAX_USE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_SCOPE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    code: str
    name: str
    description: str
    amount_type: str
    type_tax_use: str
    amount: float
    tax_scope: str
    active: _wrappers_pb2.BoolValue
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        amount_type: _Optional[str] = ...,
        type_tax_use: _Optional[str] = ...,
        amount: _Optional[float] = ...,
        tax_scope: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class TaxCreateRequest(_message.Message):
    __slots__ = [
        "code",
        "name",
        "description",
        "amount_type",
        "type_tax_use",
        "amount",
        "tax_scope",
        "external_id",
        "context",
    ]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_TYPE_FIELD_NUMBER: _ClassVar[int]
    TYPE_TAX_USE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TAX_SCOPE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    code: str
    name: str
    description: str
    amount_type: str
    type_tax_use: str
    amount: float
    tax_scope: str
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        amount_type: _Optional[str] = ...,
        type_tax_use: _Optional[str] = ...,
        amount: _Optional[float] = ...,
        tax_scope: _Optional[str] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TaxCreateResponse(_message.Message):
    __slots__ = ["tax", "response_standard"]
    TAX_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    tax: Tax
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        tax: _Optional[_Union[Tax, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class TaxReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TaxReadResponse(_message.Message):
    __slots__ = ["tax", "response_standard", "meta_data"]
    TAX_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    tax: _containers.RepeatedCompositeFieldContainer[Tax]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    def __init__(
        self,
        tax: _Optional[_Iterable[_Union[Tax, _Mapping]]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
    ) -> None: ...

class TaxUpdateRequest(_message.Message):
    __slots__ = ["tax", "context"]
    TAX_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    tax: Tax
    context: _base_pb2.Context
    def __init__(
        self, tax: _Optional[_Union[Tax, _Mapping]] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class TaxUpdateResponse(_message.Message):
    __slots__ = ["tax", "response_standard"]
    TAX_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    tax: Tax
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        tax: _Optional[_Union[Tax, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class TaxDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class TaxDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/picking_picker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dv1/stock/picking_picker.proto\x12(pro.omni.oms.api.v1.stock.picking_picker\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xa8\x02\n\rPickingPicker\x12\n\n\x02id\x18\x01 \x01(\x05\x12*\n\twarehouse\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x0cpicking_type\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x64raft\x18\x04 \x01(\x05\x12\x0f\n\x07waiting\x18\x05 \x01(\x05\x12\x11\n\tconfirmed\x18\x06 \x01(\x05\x12\x10\n\x08\x61ssigned\x18\x07 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf6\x02\n\x18PickingPickerReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf3\x01\n\x19PickingPickerReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12P\n\x0fpicking_pickers\x18\x03 \x03(\x0b\x32\x37.pro.omni.oms.api.v1.stock.picking_picker.PickingPicker2\xb7\x01\n\x14PickingPickerService\x12\x9e\x01\n\x11PickingPickerRead\x12\x42.pro.omni.oms.api.v1.stock.picking_picker.PickingPickerReadRequest\x1a\x43.pro.omni.oms.api.v1.stock.picking_picker.PickingPickerReadResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.picking_picker_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PICKINGPICKER"]._serialized_start = 157
    _globals["_PICKINGPICKER"]._serialized_end = 453
    _globals["_PICKINGPICKERREADREQUEST"]._serialized_start = 456
    _globals["_PICKINGPICKERREADREQUEST"]._serialized_end = 830
    _globals["_PICKINGPICKERREADRESPONSE"]._serialized_start = 833
    _globals["_PICKINGPICKERREADRESPONSE"]._serialized_end = 1076
    _globals["_PICKINGPICKERSERVICE"]._serialized_start = 1079
    _globals["_PICKINGPICKERSERVICE"]._serialized_end = 1262
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import ms_pb2 as v1_dot_utilities_dot_ms__pb2


class MicroserviceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MicroserviceCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceCreate",
            request_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceCreateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceCreateResponse.FromString,
        )
        self.MicroserviceRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceRead",
            request_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceReadResponse.FromString,
        )
        self.MicroserviceUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceUpdate",
            request_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceUpdateResponse.FromString,
        )
        self.MicroserviceDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceDelete",
            request_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceDeleteResponse.FromString,
        )


class MicroserviceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def MicroserviceCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def MicroserviceRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def MicroserviceUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def MicroserviceDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_MicroserviceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "MicroserviceCreate": grpc.unary_unary_rpc_method_handler(
            servicer.MicroserviceCreate,
            request_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceCreateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceCreateResponse.SerializeToString,
        ),
        "MicroserviceRead": grpc.unary_unary_rpc_method_handler(
            servicer.MicroserviceRead,
            request_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceReadResponse.SerializeToString,
        ),
        "MicroserviceUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.MicroserviceUpdate,
            request_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceUpdateResponse.SerializeToString,
        ),
        "MicroserviceDelete": grpc.unary_unary_rpc_method_handler(
            servicer.MicroserviceDelete,
            request_deserializer=v1_dot_utilities_dot_ms__pb2.MicroserviceDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_ms__pb2.MicroserviceDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.microservice.MicroserviceService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class MicroserviceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def MicroserviceCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceCreate",
            v1_dot_utilities_dot_ms__pb2.MicroserviceCreateRequest.SerializeToString,
            v1_dot_utilities_dot_ms__pb2.MicroserviceCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def MicroserviceRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceRead",
            v1_dot_utilities_dot_ms__pb2.MicroserviceReadRequest.SerializeToString,
            v1_dot_utilities_dot_ms__pb2.MicroserviceReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def MicroserviceUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceUpdate",
            v1_dot_utilities_dot_ms__pb2.MicroserviceUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_ms__pb2.MicroserviceUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def MicroserviceDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.microservice.MicroserviceService/MicroserviceDelete",
            v1_dot_utilities_dot_ms__pb2.MicroserviceDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_ms__pb2.MicroserviceDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/models_replica.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!v1/utilities/models_replica.proto\x12,pro.omni.oms.api.v1.utilities.models_replica\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xba\x01\n\x14ModelsReplicaRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12.\n\ndate_start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64\x61te_end\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x15ModelsReplicaResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12/\n\x0emodels_replica\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct2\xb3\x01\n\x14ModelsReplicaService\x12\x9a\x01\n\rModelsReplica\x12\x42.pro.omni.oms.api.v1.utilities.models_replica.ModelsReplicaRequest\x1a\x43.pro.omni.oms.api.v1.utilities.models_replica.ModelsReplicaResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.models_replica_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_MODELSREPLICAREQUEST"]._serialized_start = 166
    _globals["_MODELSREPLICAREQUEST"]._serialized_end = 352
    _globals["_MODELSREPLICARESPONSE"]._serialized_start = 355
    _globals["_MODELSREPLICARESPONSE"]._serialized_end = 502
    _globals["_MODELSREPLICASERVICE"]._serialized_start = 505
    _globals["_MODELSREPLICASERVICE"]._serialized_end = 684
# @@protoc_insertion_point(module_scope)
